@@ -2,7 +2,8 @@
 
   op <- options()
   op.googleLanguageR <- list(
-    googleAuthR.scopes.selected = "https://www.googleapis.com/auth/cloud-platform"
+    googleAuthR.scopes.selected = c("https://www.googleapis.com/auth/cloud-language",
+                                    "https://www.googleapis.com/auth/cloud-platform")
   )
 
   toset <- !(names(op.googleLanguageR) %in% names(op))
@@ -15,7 +16,8 @@
 
 .onAttach <- function(libname, pkgname){
 
-  needed <- "https://www.googleapis.com/auth/cloud-platform"
+  needed <- c("https://www.googleapis.com/auth/cloud-language",
+              "https://www.googleapis.com/auth/cloud-platform")
 
   googleAuthR::gar_attach_auto_auth(needed,
                                     environment_var = "GL_AUTH")
