@@ -1,4 +1,4 @@
-library(httptest)
+library(testthat)
 library(googleLanguageR)
 
 test_check("googleLanguageR")
